<?php

/**
 * @name DropBlock
 * @main robske_110\ForumSnippets\DropBlockOrNot
 * @version 1
 * @api 3.0.0-ALPHA9
 * @description Disables dropping blocks of blocks while enabling them again also
 * @author robske_110
 * @license LGPLv3
 */


namespace robske_110\ForumSnippets{

	use robske_110\SPC\ScriptPluginCommands;
	use pocketmine\plugin\PluginBase;
	use pocketmine\event\Listener;
	use pocketmine\event\block\BlockBreakEvent;
	use pocketmine\command\Command;
	use pocketmine\command\CommandSender;

	class DumpServerInfo extends PluginBase implements Listener{
		
		const DEFAULT_BLOCK = BlockIds::STONE;
		
		/** @var int */
		private $blockID;
		/** @var bool */
		private $disableBlock = true;
		
		public function onLoad(){
			$id = ScriptPluginCommands::initFor($this);
			ScriptPluginCommands::addCommand($id, [
				'name' => 'drop',
				'description' => 'Disables dropping blocks of blocks while enabling them again also.',
				'permission' => 'op',
				'usage' => '/drop [id]'
			]);
			$this->getServer()->getCommandMap()->registerAll($this->getDescription()->getName(), ScriptPluginCommands::getCommands($id));
		}
		
		public function onEnable(){
			$this->getServer()->getPluginManager()->registerEvents($this, $this);
		}
		
		public function onBlockBreak(BlockBreakEvent $event){
			if($this->disableBlock){
				if($event->getBlock()->getId() == $this->blockID){
					$event->setDrops([]);
				}
			}
		}
		
		public function onCommand(CommandSender $sender, Command $command, string $label, array $args): bool{
			if($command->getName() == "drop"){
				if(isset($args[0])){
					$this->blockID = $args[0];
				}else{
					$this->blockID = self::DEFAULT_BLOCK;
				}
				$this->disableBlock = !$this->disableBlock;
				$sender->sendMessage("Dropping from ".$this->blockID." has been ".($this->disableBlock ? "disabled" : "enabled"));
				return true;
			}
		}
	}
}
/** LIBARIES */
namespace robske_110\SPC{
	use pocketmine\command\PluginCommand;
	use pocketmine\Plugin\Plugin;
	
	/**
	  * @author robske_110
	  * @version 0.1.2-php7-noutils
	  */
	abstract class ScriptPluginCommands{
		private static $plugins;
		
		public static function initFor(Plugin $plugin) : int {
			self::$plugins[] = [$plugin];
			return count(self::$plugins) - 1;
		}
		
		public static function addCommand(int $id, array $data){
			if(!isset(self::$plugins[$id])){
				echo("addCommand() has been called with an unkown ID!");
			}
			$cmd = new PluginCommand($data["name"], self::$plugins[$id][0]);
			if(isset($data["description"])){
				$cmd->setDescription($data["description"]);
			}
			if(isset($data["usage"])){
				$cmd->setUsage($data["usage"]);
			}
			if(isset($data["permission"])){
				$cmd->setPermission($data["permission"]);
			}
			if(isset($data["aliases"]) && is_array($data["aliases"])){
				$aliases = [];
				foreach($data["aliases"] as $alias){
					$aliases[] = $alias;
				}
				$cmd->setAliases($aliases);
			}
			self::$plugins[$id][1][] = $cmd;
		}
		
		public static function getCommands(int $id) : array {
			if(!isset(self::$plugins[$id])){
				echo("getCommands() has been called with an unkown ID!");
			}
			return self::$plugins[$id][1];
		}
	}
}